@@ -30,6 +30,7 @@ typedef enum
 {
   TEST_SAVED_DIR = 0,
   TEST_DEFAULT,
+  TEST_FALLBACK,
   NUM_TESTS
 } TestType;
 
@@ -72,6 +73,16 @@ expand_initial_tilde (const char *path)
                       NULL);
 }
 
+static gchar *
+get_fallback_screenshot_dir (void)
+{
+  gchar *shot_dir;
+
+  shot_dir = g_strconcat ("file://", g_get_home_dir (), NULL);
+
+  return shot_dir;
+}
+
 static gchar *
 get_default_screenshot_dir (void)
 {
@@ -149,6 +160,22 @@ async_existence_job_free (AsyncExistenceJob *job)
   g_slice_free (AsyncExistenceJob, job);
 }
 
+static gboolean
+prepare_next_cycle (AsyncExistenceJob *job)
+{
+  gboolean res = FALSE;
+
+  if (job->type != (NUM_TESTS - 1))
+    {
+      (job->type)++;
+      job->iteration = 0;
+
+      res = TRUE;
+    }
+
+  return res;
+}
+
 static gboolean
 try_check_file (GIOSchedulerJob *io_job,
                 GCancellable *cancellable,
@@ -201,8 +228,13 @@ retry:
 
           if (!g_file_query_exists (parent, NULL))
             {
-              (job->type)++;
-              job->iteration = 0;
+              if (!prepare_next_cycle (job))
+                {
+                  retval = NULL;
+
+                  g_object_unref (parent);
+                  goto out;
+                }
 
               g_object_unref (file);
               g_object_unref (parent);
@@ -222,20 +254,18 @@ retry:
            * accessible.
            */
           g_free (uri);
-          if (job->type == TEST_DEFAULT)
-            {
-              retval = NULL;
-              goto out;
-            }
-          else
-            {
-              (job->type)++;
-              job->iteration = 0;
 
+          if (prepare_next_cycle (job))
+            {
               g_error_free (error);
               g_object_unref (file);
               goto retry;
             }
+          else
+            {
+              retval = NULL;
+              goto out;
+            }
         }
     }
 
@@ -265,8 +295,9 @@ screenshot_build_filename_async (GAsyncReadyCallback callback,
 
   job = g_slice_new0 (AsyncExistenceJob);
 
-  job->base_uris[0] = sanitize_save_directory (screenshot_config->save_dir);
-  job->base_uris[1] = get_default_screenshot_dir ();
+  job->base_uris[TEST_SAVED_DIR] = sanitize_save_directory (screenshot_config->save_dir);
+  job->base_uris[TEST_DEFAULT] = get_default_screenshot_dir ();
+  job->base_uris[TEST_FALLBACK] = get_fallback_screenshot_dir ();
   job->iteration = 0;
   job->type = TEST_SAVED_DIR;
 
