@@ -606,9 +606,10 @@ screenshot_get_pixbuf (GdkRectangle *rectangle)
   if (screenshot_config->take_window_shot)
     {
       method_name = "ScreenshotWindow";
-      method_params = g_variant_new ("(bbs)",
+      method_params = g_variant_new ("(bbbs)",
                                      screenshot_config->include_border,
-                                     TRUE,
+                                     screenshot_config->include_pointer,
+                                     TRUE, /* flash */
                                      filename);
     }
   else if (rectangle != NULL)
@@ -617,13 +618,16 @@ screenshot_get_pixbuf (GdkRectangle *rectangle)
       method_params = g_variant_new ("(iiiibs)",
                                      rectangle->x, rectangle->y,
                                      rectangle->width, rectangle->height,
-                                     TRUE,
+                                     TRUE, /* flash */
                                      filename);
     }
   else
     {
       method_name = "Screenshot";
-      method_params = g_variant_new ("(bs)", TRUE, filename);
+      method_params = g_variant_new ("(bbs)",
+                                     screenshot_config->include_pointer,
+                                     TRUE, /* flash */
+                                     filename);
     }
 
   connection = screenshot_application_get_session_bus ();
@@ -674,8 +678,9 @@ screenshot_show_dialog (GtkWindow   *parent,
   GtkWindowGroup *group;
   gint response;
 
-  g_return_if_fail ((parent == NULL) || (GTK_IS_WINDOW (parent)));
-  g_return_if_fail (message != NULL);
+  g_return_val_if_fail ((parent == NULL) || (GTK_IS_WINDOW (parent)),
+                        GTK_RESPONSE_NONE);
+  g_return_val_if_fail (message != NULL, GTK_RESPONSE_NONE);
   
   dialog = gtk_message_dialog_new (parent,
   				   GTK_DIALOG_DESTROY_WITH_PARENT,
